@@ -83,6 +83,7 @@ def ensure_local_plotly_files():
         for fn in [CREDENTIALS_FILE, CONFIG_FILE]:
             utils.ensure_file_exists(fn)
             contents = utils.load_json_dict(fn)
+            contents_orig = contents.copy()
             for key, val in list(FILE_CONTENT[fn].items()):
                 # TODO: removed type checking below, may want to revisit
                 if key not in contents:
@@ -91,7 +92,12 @@ def ensure_local_plotly_files():
             for key in contents_keys:
                 if key not in FILE_CONTENT[fn]:
                     del contents[key]
-            utils.save_json_dict(fn, contents)
+            # save only if contents has changed. 
+            # This is to avoid .credentials or .config file to be overwritten randomly,
+            # which we constantly keep experiencing 
+            # (sync issues? the file might be locked for writing by other process in file._permissions)
+            if contents_orig.keys() != contents.keys():
+                utils.save_json_dict(fn, contents)
 
     else:
         warnings.warn("Looks like you don't have 'read-write' permission to "
@@ -100,8 +106,7 @@ def ensure_local_plotly_files():
                       "local configuration files. No problem though! You'll "
                       "just have to sign-in using 'plotly.plotly.sign_in()'. "
                       "For help with that: 'help(plotly.plotly.sign_in)'."
-                      "\nQuestions? Visit community.plot.ly or upgrade to a "
-                      "Pro plan for 1-1 help: https://goo.gl/1YUVu9")
+                      "\nQuestions? Visit https://support.plot.ly")
 
 
 ### credentials tools ###
@@ -386,17 +391,17 @@ def embed(file_owner_or_url, file_id=None, width="100%", height=525):
     else:
         if (get_config_defaults()['plotly_domain']
                 != session.get_session_config()['plotly_domain']):
-            feedback_email = 'feedback@plot.ly'
+            feedback_contact = 'Visit support.plot.ly'
         else:
 
             # different domain likely means enterprise
-            feedback_email = 'support@plot.ly'
+            feedback_contact = 'Contact your On-Premise account executive'
 
         warnings.warn(
             "Looks like you're not using IPython or Sage to embed this "
             "plot. If you just want the *embed code*,\ntry using "
             "`get_embed()` instead."
-            '\nQuestions? {}'.format(feedback_email))
+            '\nQuestions? {}'.format(feedback_contact))
 
 
 ### mpl-related tools ###
@@ -1000,8 +1005,7 @@ def make_subplots(rows=1, cols=1,
     # Function pasting x/y domains in layout object (2d case)
     def _add_domain(layout, x_or_y, label, domain, anchor, position):
         name = label[0] + 'axis' + label[1:]
-        graph_obj = '{X_or_Y}Axis'.format(X_or_Y=x_or_y.upper())
-        axis = getattr(graph_objs, graph_obj)(domain=domain)
+        axis = {'domain': domain}
         if anchor:
             axis['anchor'] = anchor
         if isinstance(position, float):
@@ -1393,7 +1397,7 @@ def return_figure_from_figure_or_data(figure_or_data, validate_figure):
             raise exceptions.PlotlyEmptyDataError(
                 "Empty data list found. Make sure that you populated the "
                 "list of data objects you're sending and try again.\n"
-                "Questions? support@plot.ly"
+                "Questions? Visit support.plot.ly"
             )
 
     return figure
